@@ -30,11 +30,11 @@ class Recaptcha(object):
         remote_ip = request.remote_addr
 
         if not challenge or not response:
-            raise ValidationError('This field is required.')
+            raise ValidationError(field.gettext('This field is required.'))
 
         if not self._validate_recaptcha(challenge, response, remote_ip):
             field.recaptcha_error = 'incorrect-captcha-sol'
-            raise ValidationError(self.message)
+            raise ValidationError(field.gettext(self.message))
 
     def _validate_recaptcha(self, challenge, response, remote_addr):
         """Performs the actual validation."""
